:mod:`oujago.nlp.stopwords`
============================

.. automodule:: oujago.nlp.stopwords

.. autosummary::

    ChineseStopWords


Detailed Description
--------------------


.. autoclass:: ChineseStopWords
    :members:


